@@ -12,6 +12,7 @@
 #include <QDomDocument>
 #include <QFile>
 #include <QDebug>
+#include <QSharedData>
 
 #include "utils/qrefreshlist.h"
 
@@ -42,13 +43,14 @@ typedef QRefreshList<Album> AlbumList;
 #define NODE_ALBUM_ICON "icon"
 #define NODE_ALBUM_ICON_URL "iconUrl"
 
+class AlbumData;
+
 /*!
  \brief A class for album information storage.
  */
-class Album : public QObject
+class Album
 {
-    Q_OBJECT
-
+    QSharedDataPointer<AlbumData> d;
 public:
     //! Constructs an empty album.
     Album();
@@ -64,17 +66,6 @@ public:
     //! A destructor.
     ~Album();
 
-    QString albumId;     /*!< album ID from service */
-    QString ownerId;     /*!< ID of album owner */
-    QString title;       /*!< album title (optional) */
-    QString description; /*!< album description (optional) */
-    QString time_create; /*!< Unix timestamp when the album was created. */
-    QString time_update; /*!< Unix timestamp when the album was modifed. */
-    int size;            /*!< Number of images in this album */
-    QString icon;        /*!< Full path in system to the file with album's icon */
-    QString icon_url;    /*!< Permalink on the file with album's icon */
-    QString accountId;   /*!< account id which belongs to the album (not stored in cache) */
-
     /*!
      \brief Store album data to XML format.
 
@@ -119,6 +110,29 @@ public:
     */
     Album& operator=(const Album&);
 
+    // Getters
+    const QString albumId() const;
+    const QString ownerId() const;
+    const QString title() const;
+    const QString description() const;
+    const QString time_create() const;
+    const QString time_update() const;
+    int size() const;
+    const QString icon() const;
+    const QString icon_url() const;
+    const QString accountId() const;
+
+    // Setters
+    void setAlbumId(const QString& v);
+    void setOwnerId(const QString& v);
+    void setTitle(const QString& v);
+    void setDescription(const QString& v);
+    void setTime_create(const QString& v);
+    void setTime_update(const QString& v);
+    void setSize(int v);
+    void setIcon(const QString& v);
+    void setIcon_url(const QString& v);
+    void setAccountId(const QString& v);
 };
 
 Q_DECLARE_METATYPE(Album)
