@@ -1,28 +1,63 @@
 #include "photo.h"
 #include "utils/utils.h"
 
+class PhotoData : public QSharedData
+{
+public:
+    PhotoData();
+    PhotoData(const PhotoData& other);
+    ~PhotoData();
+
+    QString photoId;     //<! photo ID from service
+    QString albumId;     //<! album ID from service
+    QString ownerId;     //<! user ID from service
+    QString time_create; //<! creation time
+    QString icon_url;    //<! path to thumbnail (icon)
+    QString icon;        //<! path to downloaded icon
+    QString photo_url;   //<! path to large image
+    QString photo;       //<! path to downloaded large image
+    QString description; //<! photo description
+    QString accountId; //<! the name of account of this friend (not stored in cache)
+};
+
+PhotoData::PhotoData()
+    : QSharedData()
+{
+}
+
+PhotoData::PhotoData(const PhotoData& other)
+    : QSharedData(other),
+      photoId(other.photoId),
+      albumId(other.albumId),
+      ownerId(other.ownerId),
+      time_create(other.time_create),
+      icon_url(other.icon_url),
+      icon(other.icon),
+      photo_url(other.photo_url),
+      photo(other.photo),
+      description(other.description),
+      accountId(other.accountId)
+{
+}
+
+PhotoData::~PhotoData()
+{
+}
+
+
 Photo::Photo()
 {
+    d = new PhotoData;
 }
 
 Photo::Photo(const Photo &src)
-    : QObject(src.parent())
+    : d(src.d)
 {
-    Photo::copyData(this, &src);
 }
 
-void Photo::copyData(Photo *dst, const Photo *src)
+Photo::~Photo()
 {
-    dst->accountId = src->accountId;
-    dst->albumId = src->albumId;
-    dst->ownerId = src->ownerId;
-    dst->photoId = src->photoId;
-    dst->photo_url = src->photo_url;
-    dst->photo = src->photo;
-    dst->description = src->description;
-    dst->icon_url = src->icon_url;
-    dst->icon = src->icon;
-    dst->time_create = src->time_create;
+
 }
 
 QDomElement Photo::toQDomElement(QDomDocument& doc) const
@@ -36,43 +71,43 @@ QDomElement Photo::toQDomElement(QDomDocument& doc, const Photo& src)
 
     // ID
     QDomElement node = doc.createElement(NODE_PHOTO_ID);
-    QDomText t = doc.createTextNode(src.photoId);
+    QDomText t = doc.createTextNode(src.photoId());
     ret.appendChild(node);
     node.appendChild(t);
 
     //time create
     node = doc.createElement(NODE_PHOTO_CREATE);
-    t = doc.createTextNode(src.time_create);
+    t = doc.createTextNode(src.time_create());
     ret.appendChild(node);
     node.appendChild(t);
 
     //icon url
     node = doc.createElement(NODE_PHOTO_ICON_URL);
-    t = doc.createTextNode(src.icon_url);
+    t = doc.createTextNode(src.icon_url());
     ret.appendChild(node);
     node.appendChild(t);
 
     //icon
     node = doc.createElement(NODE_PHOTO_ICON);
-    t = doc.createTextNode(src.icon);
+    t = doc.createTextNode(src.icon());
     ret.appendChild(node);
     node.appendChild(t);
 
     //image url
     node = doc.createElement(NODE_PHOTO_IMAGE_URL);
-    t = doc.createTextNode(src.photo_url);
+    t = doc.createTextNode(src.photo_url());
     ret.appendChild(node);
     node.appendChild(t);
 
     //image
     node = doc.createElement(NODE_PHOTO_IMAGE);
-    t = doc.createTextNode(src.photo);
+    t = doc.createTextNode(src.photo());
     ret.appendChild(node);
     node.appendChild(t);
 
     //description
     node = doc.createElement(NODE_PHOTO_DESCRIPTION);
-    t = doc.createTextNode(src.description);
+    t = doc.createTextNode(src.description());
     ret.appendChild(node);
     node.appendChild(t);
 
@@ -83,34 +118,34 @@ Photo Photo::fromQDomElement(const QDomElement& fr, const QString& accountId, co
 {
     Photo ret = Photo();
 
-    ret.photoId = fr.elementsByTagName(NODE_PHOTO_ID).at(0).firstChild().toText().data();
-    ret.icon_url = fr.elementsByTagName(NODE_PHOTO_ICON_URL).at(0).firstChild().toText().data();
-    ret.icon = fr.elementsByTagName(NODE_PHOTO_ICON).at(0).firstChild().toText().data();
-    ret.time_create = fr.elementsByTagName(NODE_PHOTO_CREATE).at(0).firstChild().toText().data();
-    ret.photo_url = fr.elementsByTagName(NODE_PHOTO_IMAGE_URL).at(0).firstChild().toText().data();
-    ret.photo = fr.elementsByTagName(NODE_PHOTO_IMAGE).at(0).firstChild().toText().data();
+    ret.setPhotoId(fr.elementsByTagName(NODE_PHOTO_ID).at(0).firstChild().toText().data());
+    ret.setIcon_url(fr.elementsByTagName(NODE_PHOTO_ICON_URL).at(0).firstChild().toText().data());
+    ret.setIcon(fr.elementsByTagName(NODE_PHOTO_ICON).at(0).firstChild().toText().data());
+    ret.setTime_create(fr.elementsByTagName(NODE_PHOTO_CREATE).at(0).firstChild().toText().data());
+    ret.setPhoto_url(fr.elementsByTagName(NODE_PHOTO_IMAGE_URL).at(0).firstChild().toText().data());
+    ret.setPhoto(fr.elementsByTagName(NODE_PHOTO_IMAGE).at(0).firstChild().toText().data());
     QDomNodeList description = fr.elementsByTagName(NODE_PHOTO_DESCRIPTION);
     if (!description.isEmpty())
-        ret.description = description.at(0).firstChild().toText().data();
+        ret.setDescription(description.at(0).firstChild().toText().data());
     else
-        ret.description = "";
-    ret.accountId = accountId;
-    ret.ownerId = friendId;
-    ret.albumId = albumId;
+        ret.setDescription("");
+    ret.setAccountId(accountId);
+    ret.setOwnerId(friendId);
+    ret.setAlbumId(albumId);
 
     return ret;
 }
 
 Photo& Photo::operator =(Photo const& src)
 {
-    Photo::copyData(this, &src);
+    d = src.d;
     return *this;
 }
 
 PhotoCommentList Photo::getPhotoComments() const
 {
     PhotoCommentList ret;
-    QFile file(Utils::getAccountDir(this->accountId) + QString(FILE_PHOTO_COMMENTS_DATA).arg(this->ownerId, this->albumId, this->photoId));
+    QFile file(Utils::getAccountDir(this->accountId()) + QString(FILE_PHOTO_COMMENTS_DATA).arg(this->ownerId(), this->albumId(), this->photoId()));
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): " << file.fileName();
     if (file.open(QIODevice::ReadOnly) == false)
         return ret;
@@ -126,9 +161,9 @@ PhotoCommentList Photo::getPhotoComments() const
 
     QDomNodeList lst = doc.elementsByTagName(NODE_PHOTO_COMMENT_ROOT);
 
-    qDebug() << "Start load of " << lst.length() << " comments for " << this->photoId;
+    qDebug() << "Start load of " << lst.length() << " comments for " << this->photoId();
     for (uint i = 0; i < lst.length(); i++) {
-        ret.append(PhotoComment::fromQDomElement(lst.at(i).toElement(), this->accountId, this->ownerId, this->albumId, this->photoId));
+        ret.append(PhotoComment::fromQDomElement(lst.at(i).toElement(), this->accountId(), this->ownerId(), this->albumId(), this->photoId()));
     }
 
     qDebug() << __FILE__ << ":" << __LINE__ << ":" << __FUNCTION__ << "(): loaded " << ret.length() << " comments";
@@ -194,18 +229,41 @@ PhotoList Photo::loadPhotoList(const QString& accountId, const QString& ownerId,
 QString Photo::getKey(const PhotoList& photos)
 {
     if (photos.length() > 0)
-        return QString("photos_%1_%2").arg(photos.at(0).accountId).arg(photos.at(0).albumId);
+        return QString("photos_%1_%2").arg(photos.at(0).accountId()).arg(photos.at(0).albumId());
     else
         return QString("photos");
 }
 
 QString Photo::getKey(const Album& album)
 {
-    return QString("photos_%1_%2").arg(album.accountId).arg(album.albumId);
+    return QString("photos_%1_%2").arg(album.accountId()).arg(album.albumId());
 }
 
 QString Photo::getKey(const Photo& val)
 {
-    return QString("photos_%1_%2").arg(val.accountId).arg(val.albumId);
+    return QString("photos_%1_%2").arg(val.accountId()).arg(val.albumId());
 }
 
+// Getters
+const QString Photo::photoId() const { return d->photoId; }
+const QString Photo::albumId() const { return d->albumId; }
+const QString Photo::ownerId() const { return d->ownerId; }
+const QString Photo::time_create() const { return d->time_create; }
+const QString Photo::icon_url() const { return d->icon_url; }
+const QString Photo::icon() const { return d->icon; }
+const QString Photo::photo_url() const { return d->photo_url; }
+const QString Photo::photo() const { return d->photo; }
+const QString Photo::description() const { return d->description; }
+const QString Photo::accountId() const { return d->accountId; }
+
+// Setters
+void Photo::setPhotoId(const QString& v) { d->photoId = v; }
+void Photo::setAlbumId(const QString& v) { d->albumId = v; }
+void Photo::setOwnerId(const QString& v) { d->ownerId = v; }
+void Photo::setTime_create(const QString& v) { d->time_create = v; }
+void Photo::setIcon_url(const QString& v) { d->icon_url = v; }
+void Photo::setIcon(const QString& v) { d->icon = v; }
+void Photo::setPhoto_url(const QString& v) { d->photo_url = v; }
+void Photo::setPhoto(const QString& v) { d->photo = v; }
+void Photo::setDescription(const QString& v) { d->description = v; }
+void Photo::setAccountId(const QString& v) { d->accountId = v; }
