@@ -14,6 +14,7 @@
 #include <QMetaType>
 #include <QDomDocument>
 #include <QFile>
+#include <QSharedData>
 
 #include "utils/qrefreshlist.h"
 class Photo;
@@ -39,37 +40,18 @@ typedef QRefreshList<Photo> PhotoList;
 #define NODE_PHOTO_ICON_URL "icon_url"
 #define NODE_PHOTO_DESCRIPTION "description"
 
+class PhotoData;
 
 /*!
  \brief A class for photo information storage.
  */
-class Photo : public QObject
+class Photo
 {
-    Q_OBJECT
-
+    QSharedDataPointer<PhotoData> d;
 public:
     Photo();
     Photo(const Photo& source);
-
-    QString photoId;     //<! photo ID from service
-
-    QString albumId;     //<! album ID from service
-
-    QString ownerId;     //<! user ID from service
-
-    QString time_create; //<! creation time
-
-    QString icon_url;    //<! path to thumbnail (icon)
-
-    QString icon;        //<! path to downloaded icon
-
-    QString photo_url;   //<! path to large image
-
-    QString photo;       //<! path to downloaded large image
-
-    QString description; //<! photo description
-
-    QString accountId; //<! the name of account of this friend (not stored in cache)
+    ~Photo();
 
     // store photolist data to XML format
     QDomElement toQDomElement(QDomDocument& doc) const;
@@ -81,8 +63,6 @@ public:
     static Photo fromQDomElement(const QDomElement& fr, const QString& accountId,
                                  const QString& friendId, const QString& albumId);
 
-    static void copyData(Photo *dst, const Photo *src);
-
     Photo& operator=(const Photo& source);
 
     // load photo comments from cache file.
@@ -120,6 +100,30 @@ public:
     static QString getKey(const Album& album);
 
     static PhotoList loadPhotoList(const QString& accountId, const QString& ownerId, const QString& albumId);
+
+    // Getters
+    const QString photoId() const;
+    const QString albumId() const;
+    const QString ownerId() const;
+    const QString time_create() const;
+    const QString icon_url() const;
+    const QString icon() const;
+    const QString photo_url() const;
+    const QString photo() const;
+    const QString description() const;
+    const QString accountId() const;
+
+    // Setters
+    void setPhotoId(const QString& v);
+    void setAlbumId(const QString& v);
+    void setOwnerId(const QString& v);
+    void setTime_create(const QString& v);
+    void setIcon_url(const QString& v);
+    void setIcon(const QString& v);
+    void setPhoto_url(const QString& v);
+    void setPhoto(const QString& v);
+    void setDescription(const QString& v);
+    void setAccountId(const QString& v);
 };
 
 Q_DECLARE_METATYPE(Photo)
