@@ -1,5 +1,5 @@
-#ifndef QERRORMESSAGE_H
-#define QERRORMESSAGE_H
+#ifndef QERRORMESSAGE_MSA_H
+#define QERRORMESSAGE_MSA_H
 
 /**
   \file qerrormessage.h
@@ -72,4 +72,4 @@ public:
 
 Q_DECLARE_METATYPE(QErrorMessage)
 
-#endif // QERRORMESSAGE_H
+#endif // QERRORMESSAGE_MSA_H
