@@ -18,7 +18,25 @@ int FilterMessageReaded::filterableType() const
 bool FilterMessageReaded::isFiltered(QVariant value) const
 {
     if (enabled)
-        return value.value<Message>().isReaded();
+    {
+        Message msg = value.value<Message>();
+        for (int i = 0; i < notReaded.length(); i++)
+        {
+            if (notReaded.at(i).accountId.compare(msg.accountId()) == 0 &&
+                    notReaded.at(i).messageId.compare(msg.messageId()) == 0)
+                return false;
+
+        }
+
+        if (msg.isReaded())
+            return true;
+
+        MessageIDs msId;
+        msId.accountId = msg.accountId();
+        msId.messageId = msg.messageId();
+        this->notReaded.append(msId);
+        return false;
+    }
     else
         return false;
 }
@@ -40,5 +58,7 @@ QActionGroup* FilterMessageReaded::createActions()
 void FilterMessageReaded::actionToggled(bool state)
 {
     enabled = state;
+    if (enabled)
+        notReaded.clear();
     emitStateChanged();
 }
