@@ -3,6 +3,12 @@
 
 #include "filter/filter.h"
 
+struct MessageIDs
+{
+    QString accountId;
+    QString messageId;
+};
+
 class FilterMessageReaded : public Filter
 {
     Q_OBJECT
@@ -13,6 +19,9 @@ public:
     bool isFiltered(QVariant value) const;
     QActionGroup* createActions();
 
+private:
+    mutable QList<MessageIDs> notReaded;
+
 private slots:
     void actionToggled(bool state);
 };
