@@ -4,9 +4,9 @@
 #include <QObject>
 #include <QVariant>
 #include <QSet>
+#include <QList>
 
 #include "servicemgr.h"
-#include "widgets/filter/filterpanel.h"
 
 class ServiceMgr;
 class ServiceFilterWidget;
@@ -18,28 +18,31 @@ class QActionGroup;
 class ServiceFilter : public QObject
 {
     Q_OBJECT
-    ServiceMgr* mServiceManager;
+    ServiceMgr* mServiceManager; //!< Service manager
+
+    mutable QSet<QString> mCacheServiceNames; //!< Names of active services
+    bool mSplit; //!< Each panel has own state of filter
+    bool mDisableEventHandling; //!< Disable receiving signals from panels
+                                //!< Possibly unnessessary
 
-    mutable QSet<QString> mCacheServiceNames;
     bool isServiceActive(const DriverInfo* driver) const;
-    void fillPanel();
 
 public:
-    explicit ServiceFilter(ServiceMgr* mgr, QObject *parent = 0);
-    QWidget* createWidget();
-    void hideWidget(bool hide);
+    explicit ServiceFilter(ServiceMgr* mgr, bool split, QObject *parent = 0);
+
+    void registerFilterInterface(QObject* interface);
+    void fillPanel();
 
 signals:
-    void serviceSelected(DriverInfo* driverInfo, int index = -1);
+    void serviceSelected(DriverInfo* driverInfo);
     void itemAdded(const QIcon& icon, DriverInfo* driver, bool checked = 0);
     void itemAdded(const QString& string, DriverInfo* driver, bool checked = 0);
+    void checkItem(int index);
     void reset();
 
 public slots:
     void updateAccounts(QString str, AccountList accountList);
-
-private:
-    FilterPanel *filterPanel;
+    void selectService(DriverInfo* driverInfo, int index = -1);
 };
 
 #endif // SERVICEFILTER_H
