@@ -22,8 +22,9 @@
 
 #include "datatypes/account.h"
 #include "datatypes/driverinfo.h"
-#include "datatypes/qerrormessage.h"
+#include "datatypes/qerrormsg.h"
 #include "datatypes/message.h"
+#include "datatypes/qstatinfo.h"
 #include "utils/utils.h"
 #include "mysocials_global.h"
 
@@ -65,6 +66,10 @@ class FilterManager;
 #define SETTINGS_PROXYHOST "proxy-host"
 #define SETTINGS_AUTOROTATE "auto-rotate"
 #define SETTINGS_MULTIPANEL "multipanel"
+#define SETTINGS_ALBUM_DIRECTORY "album-directory"
+#define SETTINGS_DARK_THEME "dark-theme"
+#define SETTINGS_SHOW_SB "show-sb"
+#define SETTINGS_GROUP_FEEDS "group-feeds-by-author"
 
 /**
  \brief The service manager class.
@@ -143,7 +148,7 @@ public:
 
      \return Stored list of friends. Newest list will be sent using \sa updateFriends signal.
      */
-    FriendList getFriends(const bool isNeedUpdate, const bool useSignal);
+    FriendList getFriends(bool isNeedUpdate, bool useSignal);
 
     /**
      \brief Gets list of friend albums.
@@ -249,7 +254,7 @@ public:
       */
     MessageList getMessages(const bool isNeedUpdate, const bool useSignal);
 
-    /**
+    /*!
       \brief Delete message from service.
 
       If message was deleted successfully then signal \a messageDeleted() was called.
@@ -259,8 +264,29 @@ public:
 
       \param msg Deleted message.
       */
-    bool deleteMessage(const Message& msg);
+    void deleteMessage(const Message& msg);
 
+    /*!
+      \brief Delete message from service.
+
+      If message was deleted successfully then signal \a messageDeleted() was called.
+      Otherwise signal \a errorOccured() was called.
+
+      \sa QTransport::deleteMessage()
+
+      \param accountId The ID of account.
+
+      \param messageId The ID of deleted message.
+      */
+    void deleteMessage(const QString& accountId, const QString& messageId);
+
+    /*!
+      \brief Checks that service can send message.
+
+      \param accountId The ID of account.
+
+      \return true if service can send message, otherwise - false.
+      */
     bool canSendMessage(const QString& accountId);
 
     /**
@@ -283,11 +309,14 @@ public:
     /*!
      \brief Marks message as read.
 
+     The success result will be sent by \a messageReaded() signal.
+     Otherwise the signal \a errorOccured() was called.
+
      \param accountId ID of account to which message belongs.
 
      \param messageId ID of message.
      */
-    bool readMessage(const QString& accountId, const QString& messageId);
+    void readMessage(const QString& accountId, const QString& messageId);
 
     /**
       \brief Gets list of accounts.
@@ -305,6 +334,13 @@ public:
       */
     void addAccount(QString accountName, DriverInfo *driver);
 
+    /*!
+      \brief emit update signal for this account
+
+      \param acc Updated account.
+      */
+    void updateAccount(Account *acc);
+
     /**
       \brief Remove account from list.
 
@@ -336,6 +372,8 @@ public:
 
     QString downloadPhoto(Photo curPhoto);
 
+    bool canUploadPhoto(const QString &accountId);
+
     /**
       \brief Upload image to service.
 
@@ -453,6 +491,20 @@ public:
     FilterManager* filterManager() const;
     ServiceFilter* serviceFilter() const;
 
+    // Set mapping from panel to type
+    void setPanelToTypeMap(const QMap<int, QList<int> >& m);
+
+    bool canUpdateFriends; /**< \brief Service manager can start friend List update independently. */
+
+    bool canUpdateAlbums; /**< \brief Service manager can start album List update independently. */
+
+    bool canUpdateMessages; /**< \brief Service manager can start message List update independently. */
+
+    bool canUpdateFeeds; /**< \brief Service manager can start event feed update independently. */
+
+    //! Get list of statistics.
+    QList<QStatInfo> getStats() const;
+
 private:
     /**
      \brief List of user accounts.
@@ -515,11 +567,18 @@ private:
     DriverInfo* filteredDriver;
     ServiceFilter* serviceFilter_;
     FilterManager* filterManager_;
+    int activePanelIndex;
+    QMap<int, bool> typeNeedsUpdate;
+    QMap<int, QList<int> > panelToTypeMap;
+
     void createFilter();
 
     // Check whether AccountInfo filtered
     bool isServiceFiltered(const Account* info) const;
 
+    // Filter FriendList with ServiceFilter
+    void filterFriendList(FriendList& list) const;
+
 signals:
     /**
      * @brief Update friends list signal.
@@ -532,6 +591,8 @@ signals:
      */
     void updateFriends(FriendList list, bool isLastUpdate);
 
+    void updateFriendsNoFilters(FriendList list, bool isLastUpdate);
+
     /**
      * @brief Update album list signal
 
@@ -625,22 +686,8 @@ signals:
      */
     void updateProfile(Friend profile);
 
-    /**
-     * @brief
-     *
-     * @param accountId
-     * @param albumId
-     * @param local_file_name
-     * @param photoId
-     */
     void photoUploaded(QString accountId, QString albumId, QString local_file_name, QString photoId);
-    /**
-     * @brief
-     *
-     * @param ownerId
-     * @param title
-     * @param message
-     */
+
     void messageSent(QString ownerId, QString title, QString message);
 
     /**
@@ -652,7 +699,20 @@ signals:
 
       \param messageId The id of deleted message.
       */
-    void messageDeleted(QString messageId);
+    void messageDeleted(QString accountId, QString messageId);
+
+    /**
+      \brief Message was readed signal.
+
+      This signal sends when message was readed successfully.
+
+      \sa QTransport::messageReaded()
+
+      \param accountId THe ID of account.
+
+      \param messageId The ID of readed message.
+      */
+    void messageReaded(QString accountId, QString messageId);
 
     /**
       \brief Update feed of events signal.
@@ -667,91 +727,42 @@ signals:
       */
     void updateFeed(QEventFeedList list, QEventFeed::FeedType type, bool isLastUpdate);
 
+    void statsUpdated();
+
 private slots:
-    /**
-     * @brief
-     *
-     * @param accountid
-     * @param FriendList
-     * @param isLastUpdate
-     */
     void gotFriends(QString accountid, FriendList, bool isLastUpdate);
-    /**
-     * @brief
-     *
-     * @param accountid
-     * @param friendId
-     * @param AlbumList
-     * @param isLastUpdate
-     */
+
     void gotAlbumList(QString accountid, QString friendId, AlbumList, bool isLastUpdate);
-    /**
-     * @brief
-     *
-     * @param accountid
-     * @param friendId
-     * @param albumId
-     * @param PhotoList
-     * @param isLastUpdate
-     */
+
     void gotPhotoList(QString accountid, QString friendId, QString albumId, PhotoList, bool isLastUpdate);
-    /**
-     * @brief
-     *
-     * @param accountId
-     * @param MessageList
-     * @param isLastUpdate
-     */
+
     void gotMessageList(QString accountId, MessageList, bool isLastUpdate);
-    /**
-     * @brief
-     *
-     * @param accountId
-     * @param reqOwnerId
-     * @param profile
-     */
+
     void gotProfile(QString accountId, QString reqOwnerId, Friend profile);
-    /**
-     * @brief
-     *
-     * @param accountId
-     * @param ownerId
-     * @param albumId
-     * @param photoId
-     * @param list
-     */
+
     void gotComments(QString accountId, QString ownerId, QString albumId, QString photoId, PhotoCommentList list);
-    /**
-     * @brief
-     *
-     * @param list
-     */
+
     void storeAccounts(QString accountId, AccountList list);
 
     /**
       \brief Stores new events feed and call signal \a updateEventFeed().
 
       This slot attached to \a QTransport::eventFeedReceived().
-
-     * @param accountId
-     * @param list
-     * @param type
-     * @param isLastUpdate
      */
     void gotEventFeed(QString accountId, QEventFeedList list,
                       QEventFeed::FeedType type, bool isLastUpdate);
-    /**
-     * @brief
-     *
-     * @param accountId
-     * @param msg
-     * @param acc
-     */
-    void gotErrorMsg(QString accountId, QErrorMessage msg, QTransport::Action acc);
+
+    void gotErrorMsg(QString accountId, QErrorMsg msg, QTransport::Action acc);
+
+    void gotMessageReaded(const QString& accountId, const QString& messageId);
+
+    void gotMessageDeleted(const QString& accountId, const QString& messageId);
 
 public slots:
     void changeFilteredService(DriverInfo* driverInfo);
     void updateData(int type = -1);
+    void changeActivePanel(int index);
+
     /**
      * @brief
      *
