@@ -1,4 +1,8 @@
 #include "utils.h"
+
+#include <QSettings>
+#include "servicemgr.h"
+
 Utils::Utils()
 {
 }
@@ -46,8 +50,11 @@ QString Utils::getPhotoDir(char *serviceName)
 
 QString Utils::getPhotoDir(const QString& serviceName)
 {
-    QString path = QDesktopServices::storageLocation(QDesktopServices::PicturesLocation) + QString("/") + serviceName + QString("/");
+    QString baseDir = settings->value(SETTINGS_ALBUM_DIRECTORY).toString();
+    if (baseDir.isEmpty())
+        baseDir = QDesktopServices::storageLocation(QDesktopServices::PicturesLocation);
 
+    QString path = baseDir + QString("/") + serviceName + QString("/");
     return path;
 }
 
@@ -136,10 +143,16 @@ bool Utils::RemoveFiles(QDir &aDir, const QString& filter)
 
 QString Utils::getPhotoCommentListKey(const Photo& photo)
 {
-    return QString("comments_%1_%2").arg(photo.accountId).arg(photo.photoId);
+    return QString("comments_%1_%2").arg(photo.accountId()).arg(photo.photoId());
 }
 
 QString Utils::getFriendKey(const QString& accountId, const QString& ownerId)
 {
     return QString("friend_%1_%2").arg(accountId).arg(ownerId);
 }
+
+QSettings* Utils::settings = 0;
+void Utils::setSettings(QSettings *settings_)
+{
+    settings = settings_;
+}
