@@ -15,6 +15,8 @@
 #define ALBUM_ICONS_DIR "album_icons/"
 #define DRIVER_LIBRARY_DIR "/msa/drivers/"
 
+class QSettings;
+
 /*!
   \brief Common functions and procedures
 
@@ -22,6 +24,7 @@
   */
 class Utils
 {
+    static QSettings* settings;
 public:
     /**
       \brief Default constructor
@@ -162,6 +165,12 @@ public:
       \return String contains Friend instance key.
       */
     static QString getFriendKey(const QString& accountId, const QString& ownerId);
+
+    /**
+      \brief Set settings object
+      \param settings Settings object
+      */
+    static void setSettings(QSettings* settings);
 };
 
 #endif // UTILS_H
